Module intrinsics

Module intrinsics 

Re-exports

pub use self::crypto::Digest;
pub use self::felt::assert;
pub use self::felt::assert_eq;
pub use self::felt::assertz;

Modules

advice
Contains intrinsics for advice operations with the advice provider.
crypto
Cryptographic intrinsics for the Miden VM.
debug
felt
Felt-related intrinsics and helpers.

Structs

Felt
A Felt backed by Plonky3’s Goldilocks field element.
Word
A unit of data consisting of 4 field elements.
WordAligned
A wrapper type which ensures that the wrapped value is aligned to 32 bytes.